@@ -8,13 +8,21 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.Type;
+import org.gnu.gtk.AnchorType;
+import org.gnu.gtk.Widget;
 /**
  * The GnomeCanvasWidget is not a widget - it is a GnomeCanvasItem that
  * is capable of containing a widget. You can use a to display any
  * widget in a GnomeCanvas as if the widget were a GnomeCanvasItem.
  */
 public class CanvasWidget extends CanvasItem {
+	
+	public CanvasWidget(CanvasGroup group) {
+		super(group, gnome_canvas_widget_get_type());
+	}
+	
 	/**
 	 * Constructs an instance of CanvasWidget from a native widget resource.
 	 * @param handle The handle to the native widget.
@@ -23,16 +31,45 @@ public class CanvasWidget extends CanvasItem {
 		super(handle);
 	}
 
-	protected void noopInit() {
-	}
-
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
 	public static Type getType() {
 		return new Type(gnome_canvas_widget_get_type());
 	}
-
+	
+	public Widget getWidget() {
+		return new Widget(getWidget(getHandle()));
+	}
+	
+	public void setWidget(Widget aWidget) {
+		setWidget(getHandle(), aWidget.getHandle());
+	}
+	
+	public double getHeight() {
+		return getHeight(getHandle());
+	}
+	
+	public void setHeight(double height) {
+		setHeight(getHandle(), height);
+	}
+	
+	public double getWidth() {
+		return getWidth(getHandle());
+	}
+	
+	public void setWidth(double width) {
+		setWidth(getHandle(), width);
+	}
+	
+	public AnchorType getAnchorType() {
+		return AnchorType.intern(getAnchor(getHandle()));
+	}
+	
+	public void setAnchorType(AnchorType aType) {
+		setAnchor(getHandle(), aType.getValue());
+	}
+	
 	/****************************************
 	 * BEGINNING OF GENERATED CODE
 	 ****************************************/
